{% load inteltool_versioned_static %}

<link rel="stylesheet" href="{% aa_intel_tool_static 'aa_intel_tool/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% aa_intel_tool_static 'aa_intel_tool/css/aa-intel-tool.min.css' %}">
